==> devextreme-22.1.1-alpha-21357-0315.tgz: package/cjs/ui/diagram/ui.diagram.view_toolbar.js <==
/**
 * DevExtreme (cjs/ui/diagram/ui.diagram.view_toolbar.js)
 * Version: 22.1.0 (build 21357-0315)
 * Build date: Thu Dec 23 2021
 *
 * Copyright (c) 2012 - 2021 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
"use strict";
exports.default = void 0;
var _uiDiagram = _interopRequireDefault(require("./ui.diagram.toolbar"));
var _diagram = _interopRequireDefault(require("./diagram.commands_manager"));

function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    }
}

function _inheritsLoose(subClass, superClass) {
    subClass.prototype = Object.create(superClass.prototype);
    subClass.prototype.constructor = subClass;
    _setPrototypeOf(subClass, superClass)
}

function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function(o, p) {
        o.__proto__ = p;
        return o
    };
    return _setPrototypeOf(o, p)
}
var DiagramViewToolbar = function(_DiagramToolbar) {
    _inheritsLoose(DiagramViewToolbar, _DiagramToolbar);

    function DiagramViewToolbar() {
        return _DiagramToolbar.apply(this, arguments) || this
    }
    var _proto = DiagramViewToolbar.prototype;
    _proto._getCommands = function() {
        return _diagram.default.getViewToolbarCommands(this.option("commands"), this.option("excludeCommands"))
    };
    return DiagramViewToolbar
}(_uiDiagram.default);
var _default = DiagramViewToolbar;
exports.default = _default;
module.exports = exports.default;
module.exports.default = exports.default;

==> devextreme-22.2.1-alpha-22313-0309.tgz: package/cjs/ui/diagram/ui.diagram.view_toolbar.js <==
/**
 * DevExtreme (cjs/ui/diagram/ui.diagram.view_toolbar.js)
 * Version: 22.2.0 (build 22313-0309)
 * Build date: Wed Nov 09 2022
 *
 * Copyright (c) 2012 - 2022 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
"use strict";
exports.default = void 0;
var _uiDiagram = _interopRequireDefault(require("./ui.diagram.toolbar"));
var _diagram = _interopRequireDefault(require("./diagram.commands_manager"));

function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    }
}

function _inheritsLoose(subClass, superClass) {
    subClass.prototype = Object.create(superClass.prototype);
    subClass.prototype.constructor = subClass;
    _setPrototypeOf(subClass, superClass)
}

function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function(o, p) {
        o.__proto__ = p;
        return o
    };
    return _setPrototypeOf(o, p)
}
var DiagramViewToolbar = function(_DiagramToolbar) {
    _inheritsLoose(DiagramViewToolbar, _DiagramToolbar);

    function DiagramViewToolbar() {
        return _DiagramToolbar.apply(this, arguments) || this
    }
    var _proto = DiagramViewToolbar.prototype;
    _proto._getCommands = function() {
        return _diagram.default.getViewToolbarCommands(this.option("commands"), this.option("excludeCommands"))
    };
    return DiagramViewToolbar
}(_uiDiagram.default);
var _default = DiagramViewToolbar;
exports.default = _default;
module.exports = exports.default;
module.exports.default = exports.default;
